@@ -27,12 +27,20 @@ class DummyCurve(object):
                 # Active input and export
                 data['ae'] = data.pop('as')
                 data['ai'] = data.pop('ae')
-            if 'season' in data and isinstance(data['season'], str):
+            if 'season' in data and (isinstance(data['season'], str) or isinstance(data['season'], unicode)):
                 try:
                     data['season'] = int(data['season'])
                 except ValueError:
                     # str season
                     data['season'] = 0 if data['season'].lower() == 'w' else 1
+            if 'invoice_number' in data:
+                data['factura'] = data.pop('invoice_number')
+            if 'bill' in data:
+                data['factura'] = data.pop('bill')
+            # Transform fact in measure key if only one key passed
+            for k in ('ai_fact', 'ae_fact', 'r1_fact', 'r2_fact', 'r3_fact', 'r4_fact'):
+                if k in data and k[:2] not in data:
+                    data[k[:2]] = data.pop(k)
             for k in ('ai', 'ae', 'r1', 'r2', 'r3', 'r4'):
                 if k not in data:
                     data[k] = 0
